close all, clear all, clc

% Calculation of ballast of pontoons, including:
% 1. ballast waterplane position;
% 2. average density of ballast and steel;
% 3. check the filling ratio of cone 

rho_st = 7850;
rho_sw = 1025;
%% Mid pontoon
t1 = 0.137;     %[m], plate thickness
d1 = 17-2*t1;   %[m], bottom diameter
d2 = 8-2*t1;    %[m], mid diameter
d3 = 3.5-2*t1;  %[m], top diameter
h1 = 7;         %[m], cylinder 1 height
h2 = 2;         %[m], cylinder 2 height
h3 = 4;         %[m], cone height
Vm(1) = pi*d1^2/4*h1;                   % mid_cy_1 colume
Vm(2) = pi*d2^2/4*h2;                   % mid_cy_2 colume
Vm(3) = pi/3*h3*(d2^2+d3^2+d2*d3)/4;    % mid_cone colume
V_mid_pont = Vm(1)+Vm(2)+Vm(3);         % total volume of mid pontoon
V_mid_ball = V_mid_pont*0.377;          % volume of ballast in mid pontoon
% solve ballast x1
syms x1;
if V_mid_ball < Vm(1)
    f1 = pi*d1^2/4*x1-V_mid_ball;
    x1 = solve(f1==0);
end
x1=double(x1);
%% calculation of average density
V_m_st1     = (pi*(d1+2*t1)^2/4)*t1;  % steel volume below ballast waterplane
V_m_st2     = (pi*(d1+t1))*x1*t1;
V_m_st      = V_m_st1 +V_m_st2;
V_m_sw      = pi*d1^2/4*x1;                         % ballast volume
m_mid_st    = V_m_st*rho_st;                        % mass of steel
m_mid_sw    = V_m_sw*rho_sw;                        % mass of ballast
rho_m2      = (m_mid_st+m_mid_sw)/V_m_st2;  % average density
fprintf('ballast height in mid pontoon = %.4g m. New density if %.4g kg/m3 \n',x1,rho_m2);

%% Side pontoon
t2  = 0.062;        % [m], thickness of side pontoon
D1  = 12-2*t2;      % [m], diameter of side pontoon cylinder
D2  = 3.58-2*t2;    % [m], diameter of side pontoon cone
H1  = 7;            % [m], height of side pontoon cylinder
H2  = 6;            % [m], height of side pontoon cone
Vs(1)   = pi*D1^2/4*H1;                 % volume of side pontoon cylinder
Vs(2)   = pi/3*H2*(D1^2+D2^2+D1*D2)/4;  % volume of side pontoon cone
V_side_pont = Vs(1)+Vs(2);              % volume of whole side pontoon
fr  = [0.886,0.892,0.829,0.839];        % filling ration of cylinder(2,4,6),8,10,12
V_side_ball = V_side_pont*fr;           % designed ballast volume

% solve ballast position for side pontoons x2
for i=1:4
    syms y
    D2p = D1-(y/H2*(D1-D2));
    g = pi/3*y*(D1^2+D2p.^2+D1*D2p)/4+Vs(1)-V_side_ball(i);
    y = solve(g==0); 
    y = double(y);
    for j = 1:3
        if y(j)>0 && y(j)<H1
            x2(i)= real(y(j));
        end
    end
end

%% calculation of average density
for k = 1:4
    D2P(k)          = D1-(x2(k)/H2*(D1-D2));                        % diameter of ballast waterplane
    V_s_st1(k)      = ((pi*(D1+t2))*H1+pi*(D2P(k)+D1)/2*sqrt((D1-D2P(k))^2/4+x2(k)^2))*t2; % volume of steel below ballast waterplane
    V_s_st2(k)      = pi*(D1+2*t1)^2/4*t2;
    V_s_st(k)       = V_s_st1(k)+V_s_st2(k);
    V_s_sw(k)       = pi/3*x2(k)*(D1^2+D2P(k)^2+D1*D2P(k))/4;       % volume of ballast in the cone
    m_side_st(k)    = V_s_st(k)*rho_st;                             % mass of steel
    m_side_sw(k)    = (V_s_sw(k)+Vs(1))*rho_sw;                     % mass of ballast water
    rho_s2(k)       = (m_side_st(k)+ m_side_sw(k))/V_s_st1(k);             % new average density
    cone_ratio(k)   = V_s_sw(k)/Vs(2);                              % filling ratio of the cone
end
fprintf('ballast height in side pontoon 2,4,6 = %.4g m. New density if %.4g kg/m3, cone filling ratio is %.4g\n',x2(1),rho_s2(1),cone_ratio(1));
fprintf('ballast height in side pontoon 8 = %.4g m. New density if %.4g kg/m3, cone filling ratio is %.4g \n',x2(2),rho_s2(2),cone_ratio(2));
fprintf('ballast height in side pontoon 10 = %.4g m. New density if %.4g kg/m3, cone filling ratio is %.4g \n',x2(3),rho_s2(3),cone_ratio(3));
fprintf('ballast height in side pontoon 12 = %.4g m. New density if %.4g kg/m3, cone filling ratio is %.4g \n',x2(4),rho_s2(4),cone_ratio(4));
V = V_mid_pont+3.56^2*pi*30/4+(V_side_pont+3.56^2*pi/4*30+2.8^2*pi/4*30)*6+(2.05^2*pi/4*23+1.7^2*pi*48/4)*12;
