clear all, close all, clc
%% input information
L   = 55;                   % radial bottom beam length
a1  = 2*sin(15/180*pi)*L;   % width of total net panel
b1  = -30;                  % height of total net panel
z1  = linspace(0,b1,7);     
alpha       = 30*linspace(0,-11,12);
Cx          = cosd(alpha)*55;
Cy          = sind(alpha)*55;
SubNetPanelS= zeros(3,9,12);
sn          = 0.161;
Aside       = abs(a1*b1);
AsubnetS    = Aside/9;
%% side sub net panel center coord
for i=1:12
    if i==12
    x = linspace(Cx(i),Cx(1),7);
    y = linspace(Cy(i),Cy(1),7);
    else
    x = linspace(Cx(i),Cx(i+1),7);
    y = linspace(Cy(i),Cy(i+1),7);
    end
    SubNetPanelS(1,:,i) = [x([2,4,6]),x([2,4,6]),x([2,4,6])];
    SubNetPanelS(2,:,i) = [y([2,4,6]),y([2,4,6]),y([2,4,6])];
    SubNetPanelS(3,:,i) = z1([2,2,2,4,4,4,6,6,6]);
end
%% bottom sub net panel center coord
L2      = linspace(0,55,5);
z2      = linspace(-27,-36,5);
SubNetPanelB = zeros(3,2,12);
SubNetPanelB (1,1,:) = L2(2)* cosd(alpha-15);
SubNetPanelB (1,2,:) = L2(4)* cosd(alpha-15);
SubNetPanelB (2,1,:) = L2(2)* sind(alpha-15);
SubNetPanelB (2,2,:) = L2(4)* sind(alpha-15);
SubNetPanelB (3,1,:) = z2(4);
SubNetPanelB (3,2,:) = z2(2);
Abot    = 55*sind(15)*55*cosd(15)/cos(atan(7/51));
%% normal vector of net panel in local coordinates
for i=1:12
    Ns(i,1) = cosd(alpha(i)-15);
    Ns(i,2) = sind(alpha(i)-15);
    Ns(i,3) = 0;
    if Ns(i,1)<0
        Ns(i,:)=-Ns(i,:);
    end
end
for i=1:12
    if i == 12
        A = [cosd(alpha(i))*55,sind(alpha(i))*55,-27];
        B = [cosd(alpha(1))*55,sind(alpha(1))*55,-27];
    else   
        A = [cosd(alpha(i))*55,sind(alpha(i))*55,-27];
        B = [cosd(alpha(i+1))*55,sind(alpha(i+1))*55,-27];
    end
    C = [0,0,-36];
    a = A-C;
    b = B-C;
    c = cross(b,a);
    L = sqrt(c(1)^2+c(2)^2+c(3)^2);
    NB(i,:) = -c'/L;
    if NB(i,1)<0
        NB(i,:)= -NB(i,:);
    end
end
A = [Aside,Abot];
save ('PNVLS.dat','Ns','-ASCII');
save ('PNVLB.dat','NB','-ASCII');
save ('A.dat','A','-ASCII');
save ('SNPB.dat','SubNetPanelB','-ASCII');
save ('SNPS.dat','SubNetPanelS','-ASCII');
fid = fopen('SNPS.dat', 'r+');
fprintf(fid, '%f\n',SubNetPanelS);
fclose(fid);
fid = fopen('SNPB.dat', 'r+');
fprintf(fid, '%f\n',SubNetPanelB);
fclose(fid);

motion = load('TEST03.txt');
vx = motion(1:10001,2);
vy = motion(1:10001,3);
vz = motion(1:10001,4);
V = [vx,vy,vz];
save ('V.dat','V','-ASCII');
%% test FORCE UNDER CURRENT
% CdS = 0.04+(-0.04+0.33*sn+6.54*sn^2-4.88*sn^3)*(Ns(:,1));
% CdB = 0.04+(-0.04+0.33*sn+6.54*sn^2-4.88*sn^3)*(NB(:,1));
% u = 0.75;
% Fd1 = 0.5*1025*CdS*Aside*(u^2);
% Fd2 = 0.5*1025*CdB*Abot*(u^2);
% Fdc = sum(Fd1)+sum(Fd2)
% save ('test.dat','Fd1','-ASCII')
%% SAVE MATRIX TEST
% TESTMAT = [1,2,3;4,5,6;7,8,9]
% save ('TESTMAT.dat','TESTMAT','-ASCII');
%% wave generation and drag force calculation
zeta    = 5;
Tp      = 11;
omega   = 2*pi/Tp;
g       = 9.8;
k       = omega^2/g;
rhow    = 1025;
As      = Aside/9;
Ab      = [Abot/4,Abot/4*3];
time    = 0:0.5:5000;
for K = 1:length(time);
    t       = time(K);
    wave(K) =zeta*sin(omega*t);
    for i = 1:12
        for j = 1:9 % SIDE PANEL
            x   = SubNetPanelS(1,j,i);
            y   = SubNetPanelS(2,j,i);
            z   = SubNetPanelS(3,j,i);
%             u = 0.75;
%             v = 0;
%             w = 0;
            u   = omega*zeta*exp(k*z)*sin(omega*t-k*x);
            v   = 0*t;
            w   = omega*zeta*exp(k*z)*cos(omega*t-k*x);
%             Uw  = [u-vx(K),v-vy(K),w-vz(K)];
            Uw =[u,v,w];
            costheta    = Ns(i,:)*Uw'/norm(Uw);
            Cd          = 0.04+(-0.04+0.33*sn+6.54*sn^2-4.88*sn^3)*abs(costheta);
            FdS(i,j)    = 0.5*rhow*Cd*As*(norm(Uw))^2;
            Fdsx(i,j)   = FdS(i,j)*Uw(1)/norm(Uw);
            Fdsy(i,j)   = FdS(i,j)*Uw(2)/norm(Uw);
            Fdsz(i,j)   = FdS(i,j)*Uw(3)/norm(Uw);
            if i == 7&& j ==5
             TEST(K)=Uw(1);
            end
        end
        for j = 1:2 % BOTTOM PANEL
            x   = SubNetPanelB(1,j,i);
            y   = SubNetPanelB(2,j,i);
            z   = SubNetPanelB(3,j,i);
%             u = 0.75;
%             v = 0;
%             w = 0;
            u   = omega*zeta*exp(k*z)*sin(omega*t-k*x);
            v   = 0;
            w   = omega*zeta*exp(k*z)*cos(omega*t-k*x);
            Uw =[u,v,w];
%             Uw  = [u-vx(K),v-vy(K),w-vz(K)];
            costheta    = NB(i,:)*Uw'/norm(Uw);
            Cd          = 0.04+(-0.04+0.33*sn+6.54*sn^2-4.88*sn^3)*abs(costheta);
            FdB(i,j)    = 0.5*rhow*Cd*Ab(j)*(norm(Uw))^2;
            Fdbx(i,j)   = FdB(i,j)*Uw(1)/norm(Uw);
            Fdby(i,j)   = FdB(i,j)*Uw(2)/norm(Uw);
            Fdbz(i,j)   = FdB(i,j)*Uw(3)/norm(Uw);
         end
    end
    sFdx(K) = sum(sum(Fdsx));
    sFdx(K) = sum(sum(Fdsx))+sum(sum(Fdbx));
    sFdy(K) = sum(sum(Fdsy))+sum(sum(Fdby));
    sFdz(K) = sum(sum(Fdsz))+sum(sum(Fdbz)); 
end
plot(time,sFdx);
figure
plot(time,sFdy);
figure
plot(time,sFdz);

% mo = load('TEST01.txt');
% Vx = mo(1:10001,2);
% figure
% plot(time,vx,time,Vx);
% figure
% plot(time,Vx);
